@@ -8,7 +8,7 @@ package App::MatrixTool;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Getopt::Long qw( GetOptionsFromArray );
 use Future;
@@ -140,7 +140,7 @@ sub run_command_in_runner
    if( $runner->can( "OPTIONS" ) ) {
       my %optvalues;
 
-      GetOptionsFromArray( \@args,
+      $opt_parser->getoptionsfromarray( \@args,
          map { $_->getopt => \$optvalues{ $_->name } } $runner->OPTSPECS
       ) or exit 1;
 
