@@ -8,8 +8,9 @@ package App::MatrixTool::HTTPClient;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
+use Carp;
 use Future 0.33; # ->catch
 use Future::Utils qw( repeat_until_success );
 use IO::Async::Loop;
@@ -154,10 +155,17 @@ sub request
    );
    $req->protocol( "HTTP/1.1" );
 
-   if( defined $params{content} and ref $params{content} ) {
-      $req->content( encode_json( delete $params{content} ) );
+   if( defined $params{content} ) {
+      if( ref $params{content} ) {
+         $req->content( encode_json( delete $params{content} ) );
+         $req->header( Content_type => "application/json" );
+      }
+      else {
+         $req->content( delete $params{content} );
+         $req->header( Content_type => delete $params{content_type} //
+            croak "Non-reference content needs 'content_type'" );
+      }
       $req->header( Content_length => length $req->content );
-      $req->header( Content_type => "application/json" );
    }
 
    if( $self->{print_request} ) {
@@ -178,7 +186,7 @@ sub request
          } @res );
       });
    }
-   elsif( $path =~ m{^/_matrix/client/} ) {
+   elsif( $path =~ m{^/_matrix/(?:client|media)/} ) {
       my ( $server, $port ) = $params{server} =~ m/^([^:]+)(?::(\d+))?$/ or
          die "Unable to parse server '$params{server}'\n";
       $resolve_f = Future->done(
